#[non_exhaustive]pub enum DeleteEventSourceError {
ConcurrentModificationException(ConcurrentModificationException),
InvalidStateException(InvalidStateException),
ResourceNotFoundException(ResourceNotFoundException),
AccessDeniedException(AccessDeniedException),
InternalException(InternalException),
InvalidInputException(InvalidInputException),
ThrottlingException(ThrottlingException),
Unhandled(Unhandled),
}Expand description
Error type for the DeleteEventSourceError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConcurrentModificationException(ConcurrentModificationException)
Another change to the resource is already in progress. Retry the request.
InvalidStateException(InvalidStateException)
The resource is not in a state that allows the operation. For example, an event bus that is still being created cannot accept events.
ResourceNotFoundException(ResourceNotFoundException)
The resource does not exist.
AccessDeniedException(AccessDeniedException)
The caller does not have the permissions required to perform the operation. This error is also returned when the operation cannot use the AWS KMS key for the event bus.
InternalException(InternalException)
The request failed because of an internal service error. Retry the request.
InvalidInputException(InvalidInputException)
A request parameter is missing or not valid.
ThrottlingException(ThrottlingException)
The request was throttled because it exceeds a request rate limit. Retry the request with backoff.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl DeleteEventSourceError
impl DeleteEventSourceError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DeleteEventSourceError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DeleteEventSourceError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_concurrent_modification_exception(&self) -> bool
pub fn is_concurrent_modification_exception(&self) -> bool
Returns true if the error kind is DeleteEventSourceError::ConcurrentModificationException.
Sourcepub fn is_invalid_state_exception(&self) -> bool
pub fn is_invalid_state_exception(&self) -> bool
Returns true if the error kind is DeleteEventSourceError::InvalidStateException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is DeleteEventSourceError::ResourceNotFoundException.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is DeleteEventSourceError::AccessDeniedException.
Sourcepub fn is_internal_exception(&self) -> bool
pub fn is_internal_exception(&self) -> bool
Returns true if the error kind is DeleteEventSourceError::InternalException.
Sourcepub fn is_invalid_input_exception(&self) -> bool
pub fn is_invalid_input_exception(&self) -> bool
Returns true if the error kind is DeleteEventSourceError::InvalidInputException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is DeleteEventSourceError::ThrottlingException.